<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>ངོ་གདོང་ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>ར་འཕྲོད་པ།</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་%nབྱེད་ཆོག</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་1བྱེད་ཆོག</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>ཁྱེད་ཀྱི་ངོ་གདོང་IDར་སྤྲོད་བྱེད་རོགས། </translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>ངོ་གདོང་IDསྒོ་ལྕགས་བརྒྱབ་ཟིན་པས། གསང་ཨང་ནང་འཇུག་བྱེད།</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>སྐར་མ་%nརྗེས་ཡང་བསྐྱར་(གཅིག)ཚོད་ལྟ་བྱེད།</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>མཛུབ་རིས་ར་སྤྲོད་བྱེད།</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>ར་འཕྲོད་པ།</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་%nབྱེད་ཆོག</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་1བྱེད་ཆོག</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>མཛུབ་རིས་སྒོ་ལྕགས་བརྒྱབ་ཟིན་པས། གསང་ཨང་ནང་འཇུག་བྱེད་རོགས།</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>སྐར་མ་ %n རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ(གཅིག)བྱེད།</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>སྐར་མ་1རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>མིག་འབྲས་ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>ར་འཕྲོད་པ།</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་%nབྱེད་ཆོག</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་1བྱེད་ཆོག</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>ཁྱེད་ཀྱི་མིག་འབྲས་IDར་སྤྲོད་བྱེད་རོགས། </translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>མིག་འབྲས་IDསྒོ་ལྕགས་བརྒྱབ་ཟིན་པས། གསང་ཨང་ནང་འཇུག་བྱེད།</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>སྐར་མ་ %n རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>ར་འཕྲོད་པ།</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་%nབྱེད་ཆོག</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་1བྱེད་ཆོག</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>གསང་ཨང་ནོར་འདུག</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>སྐར་མ་ %n རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ(གཅིག) བྱེད།</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>སྐར་མ་1རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>སྐར་མ་%nརྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>གསང་ཨང་བསྐྱར་བཟོ།</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>གསང་ཨང་བརྗེད་འདུག་གམ།</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>སྐར་མ་1རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>སྐར་མ་%nརྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>གསང་ཨང་བསྐྱར་བཟོ།</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>གསང་ཨང་བརྗེད་འདུག་གམ།</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>ར་འཕྲོད་པ།</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་%nབྱེད་ཆོག</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>ར་སྤྲོད་ཐུབ་མ་སོང་། ཁྱེད་ཀྱིས་ད་དུང་ལྟ་ཚོད་1བྱེད་ཆོག</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PINནོར་འཁྲུལ།</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKEYསྤྱད་དེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>UKEYངོས་ཟིན་པས། PINནང་འཇུག་བྱེད་དགོས།</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>སྐར་མ་ %n རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>སྐར་མ་1རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>སྐར་མ་%nརྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>རྩིས་ཁྲ། </translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>གསང་ཨང་ཉིན་%nརྗེས་དུས་ཚད་འཐིམ་པས་དུས་ཐོག་ཏུ་བཟོ་བཅོས་བྱོས།</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>གསང་ཨང་དུས་ཚོད་ཡོལ་ཟིན་པས། བཟོ་བཅོས་བྱེད་རོགས།</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>རྩིས་ཁྲ་ནོར་བ།</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>གསང་ཨང་ནོར་འདུག</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>བརྙན་ཡོལ་སྒོ་ལྕགས་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>བརྙན་ཡོལ་སྒོ་ལྕགས་རྒྱག་མ་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>མཛུབ་རིས་གསང་ཨང་ར་སྤྲོད་བྱེད་པ་དུས་ཚོད་ལས་ཡོལ་ཟིན་པས། ལག་ཐབས་ཀྱིས་ནང་འཇུག་བྱེད་རོགས།</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>མཛུབ་རིས་ཀྱིས་སྒོ་ལྕགས་ཕྱེ་ཐུབ་མ་སོང་།</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>གློག་ཀླད་འདིའི་སྟེང་ད་དུང་གོང་གི་རྩིས་ཁྲ་དག་ཐོ་འཇུག་བྱས་ཡོད། གློག་ཀླད་ཁ་བརྒྱབ་ཚེ་གཞི་གྲངས་བརླག་སྲིད་པས། གློག་ཀླད་འདི་ཁ་རྒྱག་དགོས་སམ།</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>གློག་ཀླད་འདིའི་སྟེང་ད་དུང་གོང་གི་རྩིས་ཁྲ་དག་ཐོ་འཇུག་བྱས་ཡོད། གློག་ཀླད་བསྐྱར་སློང་བྱས་ཚེ་གཞི་གྲངས་བརླག་སྲིད་པས། གློག་ཀླད་འདི་བསྐྱར་སློང་བྱ་དགོས་སམ།</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>ཁྱེད་ཀྱིས་རིམ་པ་མཐོ་བའི་སྲུང་སྐྱོབ་ཁ་ཕྱེ་ཡོད་པས། Waylandལ་བརྗེ་ཐབས་མེད། ཁྱེད་ཀྱིས་“བདེ་འཇགས་ལྟེ་གནས་”ནས་རིམ་པ་མཐོ་བའི་སྲུང་སྐྱོབ་ཁ་བརྒྱབ་རྗེས་ཚོད་ལྟ་བྱེད་དང་།</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>ཁ་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>སྒུག་སྡོད།</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>མལ་གསོ།</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ཟྭ་རྒྱག</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ཐོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>སྤྱོད་མཁན་བརྗེ་བ།</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>རྒྱུད་ཁོངས་བརྗེ་བ།</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>རྒྱུད་ཁོངས་ཀྱི་ལྟ་ཆས་འགོ་སློང་།</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>གོང་གི་བྱ་རིམ་ཁ་མ་རྒྱོབ། བཙན་ཤེད་ཀྱིས་ཁ་བརྒྱབ་ཚེ་གཞི་གྲངས་བརླག་སྲིད།</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>ཁྱོད་ཀྱིས་“འདོར་བ་”ཞེས་པ་མནན་རྗེས་བྱ་རིམ་འདི་དག་ཁ་བརྒྱབ་ཆོག</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>གོང་གི་བྱ་རིམ་བསྐྱར་སློང་མ་བྱེད། བཙན་ཤེད་ཀྱིས་བསྐྱར་སློང་བྱས་ཚེ་གཞི་གྲངས་བརླག་སྲིད།</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>གོང་གི་བྱ་རིམ་སྒུག་ཏུ་སྡོད་མ་བཅུག བཙན་ཤེད་ཀྱིས་སྒུག་ཏུ་སྡོད་དུ་བཅུག་ཚེ་གཞི་གྲངས་བརླག་སྲིད།</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>གོང་གི་བྱ་རིམ་མལ་གསོ་རུ་མ་བཅུག བཙན་ཤེད་ཀྱིས་མལ་གསོ་རུ་བཅུག་ཚེ་གཞི་གྲངས་བརླག་སྲིད།</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>གོང་གི་བྱ་རིམ་ཐོ་འདོར་དུ་མ་བཅུག བཙན་ཤེད་ཀྱིས་ཐོ་འདོར་དུ་བཅུག་ཚེ་གཞི་གྲངས་བརླག་སྲིད།</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>ཁ་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>སྒུག་སྡོད།</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>མལ་གསོ།</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ཐོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>ཁྱོད་ཀྱི་ཁ་རྒྱག་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>ཁྱོད་ཀྱི་བསྐྱར་སློང་བྱེད་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>ཁྱོད་ཀྱི་ཐོ་འདོར་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>ཁ་རྒྱོབ། </translation>
    </message>
</context>
</TS>